@@ -152,36 +152,26 @@ def process_response(
     if not entity:
         return None
 
-    print(f"\n[DEBUG] Processing entity: {entity.__class__.__name__}")
-    print(f"[DEBUG] Entity dict: {entity.__dict__}")
-
     # 모든 필드 처리
     result = process_columns(entity)
-    print(f"[DEBUG] After process_columns: {result}")
     
     # Relationship 처리 (이미 로드된 관계만 처리)
     for relationship in entity.__mapper__.relationships:
-        print(f"\n[DEBUG] Processing relationship: {relationship.key}")
         if not relationship.key in entity.__dict__:
-            print(f"[DEBUG] Relationship {relationship.key} not in entity.__dict__")
             continue
             
         try:
             value = getattr(entity, relationship.key)
-            print(f"[DEBUG] Relationship value: {value}")
             
             # response_model이 있는 경우 해당 필드의 annotation type을 가져옴
             nested_response_model = None
             if response_model and relationship.key in response_model.model_fields:
                 field_info = response_model.model_fields[relationship.key]
                 nested_response_model = field_info.annotation
-                print(f"[DEBUG] Found nested response model for {relationship.key}: {nested_response_model}")
                 
                 # Optional[ProjectResponse] 같은 경우 실제 모델 추출
                 if hasattr(nested_response_model, '__origin__') and nested_response_model.__origin__ is Union:
-                    print(f"[DEBUG] Extracting actual model from Union type: {nested_response_model.__args__}")
                     nested_response_model = next((t for t in nested_response_model.__args__ if hasattr(t, 'model_fields')), None)
-                    print(f"[DEBUG] Extracted model: {nested_response_model}")
             
             if value is not None:
                 if isinstance(value, list):
@@ -190,39 +180,28 @@ def process_response(
                         for item in value
                     ]
                 else:
-                    print(f"[DEBUG] Processing single value with model: {nested_response_model}")
                     result[relationship.key] = process_response(value, nested_response_model)
-                print(f"[DEBUG] After processing relationship {relationship.key}: {result[relationship.key]}")
             else:
                 result[relationship.key] = None
         except Exception as e:
-            print(f"[DEBUG] Error processing relationship {relationship.key}: {str(e)}")
             import traceback
-            print(f"[DEBUG] Full traceback: {traceback.format_exc()}")
             result[relationship.key] = None
 
-    print(f"\n[DEBUG] Before response model processing: {result}")
     # response_model이 있는 경우 필터링
     if response_model:
-        print(f"[DEBUG] Response model fields: {response_model.model_fields}")
         # 현재 키 목록을 저장
         current_keys = list(result.keys())
         # response_model에 없는 키 제거
         for key in current_keys:
             if key not in response_model.model_fields:
-                print(f"[DEBUG] Removing key not in response model: {key}")
                 result.pop(key)
         # 모델 검증 및 업데이트
         try:
             validated_result = response_model(**result).model_dump()
-            print(f"[DEBUG] After validation: {validated_result}")
             result.update(validated_result)
         except Exception as e:
-            print(f"[DEBUG] Error during validation: {str(e)}")
             import traceback
-            print(f"[DEBUG] Full validation traceback: {traceback.format_exc()}")
-            
-    print(f"[DEBUG] Final result: {result}")
+
     return result
 
 ##################
@@ -362,7 +341,7 @@ async def update_entity(
             raise CustomException(
                 ErrorCode.NOT_FOUND,
                 detail=f"{model.__name__}|{conditions}.",
-                source_function="database.update_entity"
+                source_function="database.update_entity.not_entity"
             )
 
         # 기존 데이터를 딕셔너리로 변환
@@ -415,7 +394,7 @@ async def delete_entity(
             raise CustomException(
                 ErrorCode.NOT_FOUND,
                 detail=f"{model.__name__}|{conditions}.",
-                source_function="database.delete_entity"
+                source_function="database.delete_entity.not_entity"
             )
 
         entity.is_deleted = True
@@ -480,17 +459,13 @@ async def list_entities(
         List[Dict[str, Any]]: 쿼리 결과 리스트.
     """
     try:
-        query = select(model)
-
-        # 명시적 조인 적용
+        # 기본 쿼리 생성
         if explicit_joins:
+            query = select(model, *explicit_joins)
             for join_target in explicit_joins:
                 query = query.outerjoin(join_target)
-
-        # 조인 로딩 적용
-        if loading_joins:
-            for join_option in loading_joins:
-                query = query.options(join_option)
+        else:
+            query = select(model)
 
         # 필터 조건 적용
         if filters:
